# apistar_settings

A "Settings" component for [API Star].


## Requirements

* [API Star] 0.4+


## Installation

Use [pipenv] (or plain pip) to install the package:

    pipenv install apistar_settings


## Usage

See [test_apistar_settings.py] for examples.

[test_apistar_settings.py]: https://github.com/Bogdanp/apistar_settings/blob/master/test_apistar_settings.py


## License

apistar_settings is licensed under Apache 2.0.  Please see [LICENSE]
for licensing details.


[API Star]: https://github.com/encode/apistar/
[pipenv]: https://docs.pipenv.org
[LICENSE]: https://github.com/Bogdanp/apistar_settings/blob/master/LICENSE
